/*
 * Software License Agreement (BSD License)
 *
 * Copyright (c) 2010, Kyoto University and Honda Motor Co.,Ltd. All rights reserved.
 *
 * HARK was developed by researchers in Okuno Laboratory at the Kyoto University and 
 * Honda Research Institute Japan Co.,Ltd.
 *
 * Redistribution and use in source and binary forms, with or without modification, are 
 * permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this list 
 *    of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, this 
 *    list of conditions and the following disclaimer in the documentation and/or other 
 *    materials provided with the distribution.
 *  * Neither the name of Kyoto University and Honda Motor Co.,Ltd., Inc. nor the names 
 *    of its contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
 * SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCI-
 * DENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSI-
 * NESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTR-
 * ACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "CvfdColor.h"
#include <iostream>

using namespace std;
using namespace FD;
   
DECLARE_TYPE(CvfdColor);
   
CvfdColor::CvfdColor()
{
  int status = cvGetErrMode();
  cvSetErrMode( CV_ErrModeSilent );
  __BEGIN__; 
  OPENCV_CALL(m_Color = CV_RGB(0,0,0));         
  __END__;
  cvSetErrMode( status );
  if( cvGetErrStatus() != CV_StsOk  )
    {
      throw new GeneralException("OPENCV - Error to construct the RGB color: " +  CCHAR(cvErrorStr( cvGetErrStatus() )),__FILE__,__LINE__);
    }       
}
   
CvfdColor::CvfdColor(int channel1, int channel2, int channel3)
{
  int status = cvGetErrMode();
  cvSetErrMode( CV_ErrModeSilent );
  __BEGIN__; 
  OPENCV_CALL(m_Color = cvScalar(channel1,channel2,channel3));         
  __END__;
  cvSetErrMode( status );
  if( cvGetErrStatus() != CV_StsOk  )
    {
      throw new GeneralException("OPENCV - Error to construct the RGB color: " +  CCHAR(cvErrorStr( cvGetErrStatus() )),__FILE__,__LINE__);
    } 
}
double CvfdColor::channel3()
{
  return m_Color.val[2];
}
double CvfdColor::channel2()
{
  return m_Color.val[1];
}
double CvfdColor::channel1()
{  
  return m_Color.val[0];
}
CvfdColor::~CvfdColor()
{
      
}
   
/**Serialize (binary) the object to a stream*/
void CvfdColor::serialize(std::ostream &out) const
{
      
}
   
/**Unserialize (binary) the object from a stream*/
void CvfdColor::unserialize(std::istream &in)
{
      
}
   
/**Generic print function*/
void CvfdColor::printOn(std::ostream &out) const
{
  out << "CvfdColor ";
  out << &m_Color;		
}
   
/**Generic read function*/
void CvfdColor::readFrom(std::istream &in)
{
      
}
   
CvScalar CvfdColor::getColor()
{
  return m_Color;
}
   
