/*
 * Software License Agreement (BSD License)
 *
 * Copyright (c) 2010, Kyoto University and Honda Motor Co.,Ltd. All rights reserved.
 *
 * HARK was developed by researchers in Okuno Laboratory at the Kyoto University and 
 * Honda Research Institute Japan Co.,Ltd.
 *
 * Redistribution and use in source and binary forms, with or without modification, are 
 * permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice, this list 
 *    of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice, this 
 *    list of conditions and the following disclaimer in the documentation and/or other 
 *    materials provided with the distribution.
 *  * Neither the name of Kyoto University and Honda Motor Co.,Ltd., Inc. nor the names 
 *    of its contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY 
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES 
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT 
 * SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCI-
 * DENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, 
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSI-
 * NESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTR-
 * ACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY 
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "CvfdVideo.h"

using namespace std;
using namespace FD;
   
DECLARE_TYPE(CvfdVideo);
   
CvfdVideo::CvfdVideo()
  : m_video(NULL)
{
}
   
CvfdVideo::CvfdVideo(CvCapture* video)
{      
  m_video = video;      
}   
   
CvfdVideo::~CvfdVideo()
{
  cvReleaseCapture( &m_video );
}
   
CvfdVideo::CvfdVideo(const std::string &path)
{
  int status = cvGetErrMode();
  cvSetErrMode( CV_ErrModeSilent );
  __BEGIN__;
  OPENCV_CALL(m_video = cvCaptureFromFile(path.c_str()));
  __END__;
  cvSetErrMode( status );
  if( cvGetErrStatus() != CV_StsOk  )
    {
      throw new GeneralException("OPENCV - Error to load the video: " +  CCHAR(cvErrorStr( cvGetErrStatus() )),__FILE__,__LINE__);
    }
}
   
CvfdVideo::CvfdVideo(const int index)
{
  int status = cvGetErrMode();
  cvSetErrMode( CV_ErrModeSilent );
  __BEGIN__;
  OPENCV_CALL(m_video = cvCaptureFromCAM( index ));
  __END__;
  cvSetErrMode( status );
  if( cvGetErrStatus() != CV_StsOk  )
    {
      throw new GeneralException("OPENCV - Error to load the video: " +  CCHAR(cvErrorStr( cvGetErrStatus() )),__FILE__,__LINE__);
    }
}   
   
/**Serialize (binary) the object to a stream*/
void CvfdVideo::serialize(std::ostream &out) const
{
      
}
   
/**Unserialize (binary) the object from a stream*/
void CvfdVideo::unserialize(std::istream &in)
{
      
}
   
/**Generic print function*/
void CvfdVideo::printOn(std::ostream &out) const
{
  out << "CvfdVideo: ";
  out << m_video;
}
   
/**Generic read function*/
void CvfdVideo::readFrom(std::istream &in)
{
      
}
   
CvCapture* CvfdVideo::getVideo()
{
  return m_video;
}
